@@ -206,9 +206,6 @@ atk_text_get_character_at_offset (AtkText      *text,
 
   g_return_val_if_fail (ATK_IS_TEXT (text), (gunichar) 0);
 
-  if (offset < 0)
-    return (gunichar) 0;
-
   iface = ATK_TEXT_GET_IFACE (text);
 
   if (iface->get_character_at_offset)
@@ -377,9 +374,6 @@ atk_text_get_text_at_offset (AtkText          *text,
   else
     real_end_offset = &local_end_offset;
 
-  if (offset < 0)
-    return NULL;
-
   iface = ATK_TEXT_GET_IFACE (text);
 
   if (iface->get_text_at_offset)
@@ -1023,7 +1017,7 @@ atk_text_attribute_get_name (AtkTextAttribute attr)
 {
   GTypeClass *type_class;
   GEnumValue *value;
-  gchar *name = NULL;
+  const gchar *name = NULL;
 
   type_class = g_type_class_ref (ATK_TYPE_TEXT_ATTRIBUTE);
   g_return_val_if_fail (G_IS_ENUM_CLASS (type_class), NULL);
@@ -1129,10 +1123,10 @@ atk_text_attribute_get_value (AtkTextAttribute attr,
       g_assert (index >= 0 && index < 2);
       return bool[index];
     case ATK_TEXT_ATTR_UNDERLINE:
-      g_assert (index >= 0 && index < 4);
+      g_assert (index >= 0 && index < 5);
       return underline[index];
     case ATK_TEXT_ATTR_WRAP_MODE:
-      g_assert (index >= 0 && index < 3);
+      g_assert (index >= 0 && index < 4);
       return wrap_mode[index];
     case ATK_TEXT_ATTR_DIRECTION:
       g_assert (index >= 0 && index < 3);
